@@ -5,7 +5,7 @@ from cmind import utils
 
 class CAutomation(Automation):
     """
-    Automation actions for the automation module
+    CM "automation" automation actions
     """
 
     ############################################################
@@ -15,10 +15,22 @@ class CAutomation(Automation):
     ############################################################
     def add(self, i):
         """
-        Add automation
+        Add CM automation.
 
         Args:
-           (artifact) (str) - repository name or UID
+          (CM input dict): 
+
+          (out) (str): if 'con', output to console
+
+          parsed_artifact (list): prepared in CM CLI or CM access function
+                                    [ (artifact alias, artifact UID) ] or
+                                    [ (artifact alias, artifact UID), (artifact repo alias, artifact repo UID) ]
+
+        Returns:
+          (CM return dict):
+
+          * return (int): return code == 0 if no error and >0 if error
+          * (error) (str): error string if return>0
            
         """
 
@@ -31,14 +43,19 @@ class CAutomation(Automation):
         artifact_obj = parsed_artifact[0] if len(parsed_artifact)>0 else ('','')
 
         module_name = 'module.py'
-        
-        # Add placeholder
+
+        tags_list = utils.convert_tags_to_list(i)
+        if 'automation' not in tags_list: tags_list.append('automation')
+
+        # Add placeholder (use common action)
         i['out']='con'
         i['common']=True
         
         i['meta']={'automation_alias':self.meta['alias'],
                    'automation_uid':self.meta['uid'],
-                   'tags':['automation',module_name]}
+                   'tags':tags_list}
+
+        if 'tags' in i: del(i['tags'])
 
         r_obj=self.cmind.access(i)
         if r_obj['return']>0: return r_obj
